#!/bin/sh
#
# DESCRIPTION:
# This script is used to create TMTP database and tables manually for DB2
#
# USAGE:
# crtdb_db2 db2_version dbname dbuser dbpasswd country_code
#
printMessage() {

    msgId=$1

    if [ "$JAVA_BIN" = "" ]; then
      if [ "$msgId" = "crtdbUsage" ]; then
        $ECHO ""
        $ECHO "Usage: crtdb_db2.sh db2_version dbname dbuser dbpasswd country_code create_db was_user"
        $ECHO "  where"
        $ECHO "   db2_version can be 8.1, 8.2, or 9.1"
        $ECHO "   dbname is TMTP database name, e.g. tmtp"
        $ECHO "   dbuser is db2 admin user"
        $ECHO "   dbpasswd is the db2admin password"
        $ECHO "   country_code is locale name as understood by DB2"
        $ECHO "   create_db is either Y or N, Y creates a new database"
        $ECHO "   was_user is the user WAS is running under"
        $ECHO "  e.g. crtdb_db2.sh 8.1 tmtp db2admin db2passwd US Y root"
      fi
    else
       $JAVA_BIN $msgId
    fi

}



################################################
##                BEGIN MAIN                  ##
################################################

# Turn off trace
set +x

# Get the arguments
DB2VERSION=$1
DBNAME=$2
DBUSER=$3
DBPASSWD=$4
COUNTRY_CODE=$5
CREATE_DB=$6
WAS_USER=$7

TEMP_FILE=/tmp/itcam_db2.sql
UTILDIR=`dirname $0`

CLP="-Djava.class.path=${UTILDIR}/../scripts/install.jar com.ibm.tivoli.transperf.util.DisplayMessage"
export CLP

# Verify if java home has been defined
if [ "$JAVA_HOME" = "" ]; then
    JAVA_BIN="${UTILDIR}/../java/jre/bin/java $CLP"
    if [ -f "$JAVA_BIN" ]; then
        export JAVA_BIN
    else
        unset JAVA_BIN
    fi
fi

if [ "$JAVA_HOME" != "" ]; then
    JAVA_BIN="$JAVA_HOME/bin/java $CLP"
    export JAVA_BIN
fi

# commands used
ECHO="echo"

# verify all args passed in are not null
if [ "$DB2VERSION" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi
if [ "$DB2VERSION" != "8.1" ]; then
    if [ "$DB2VERSION" != "8.2" ]; then
         if [ "$DB2VERSION" != "9.1" ]; then
             if [ "$DB2VERSION" != "9.2" ]; then
                 printMessage crtdbUsage
                 exit 1
             fi
         fi
    fi
fi
if [ "$DB2VERSION" != "9.2" ]; then
   if [ "$DB2VERSION" != "9.1" ]; then
      if [ "$DB2VERSION" != "8.2" ]; then
          if [ "$DB2VERSION" != "8.1" ]; then
             printMessage crtdbUsage
             exit 1
          fi
      fi
   fi
fi

if [ "$DBNAME" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi
if [ "$DBUSER" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi
if [ "$DBPASSWD" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi
if [ "$COUNTRY_CODE" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi
if [ "$CREATE_DB" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi
if [ "$CREATE_DB" != "Y" ]; then
    if [ "$CREATE_DB" != "N" ]; then
        printMessage crtdbUsage
        exit 1
    fi
fi
if [ "$CREATE_DB" != "N" ]; then
    if [ "$CREATE_DB" != "Y" ]; then
        printMessage crtdbUsage
        exit 1
    fi
fi
if [ "$WAS_USER" = "" ]; then
    printMessage crtdbUsage
    exit 1
fi

if [ "$CREATE_DB" = "Y" ]; then
printMessage crtdbCreating
db2 create database "$DBNAME" USING CODESET UTF-8 TERRITORY "$COUNTRY_CODE"
db2 connect to "$DBNAME" user "$DBUSER" using "$DBPASSWD"
db2 create bufferpool buffpool32k size 100 pagesize 32k
db2 update db cfg using LOCKLIST 150
db2 update db cfg using MAXLOCKS 35
fi

if [ "$CREATE_DB" = "N" ]; then
db2 connect to "$DBNAME" user "$DBUSER" using "$DBPASSWD"
fi

# 8.1 and 8.2 run same scripts for now
if [ "$DB2VERSION" = "8.1" ]; then
db2 -tf ${UTILDIR}/DB2UDB_V81/db2_createTableSpace.ddl
db2 -tf ${UTILDIR}/DB2UDB_V81/Table.ddl
fi

if [ "$DB2VERSION" = "8.2" ]; then
db2 -tf ${UTILDIR}/DB2UDB_V81/db2_createTableSpace.ddl
db2 -tf ${UTILDIR}/DB2UDB_V81/Table.ddl
fi

if [ "$DB2VERSION" = "9.2" ]; then
db2 -tf ${UTILDIR}/DB2UDB_V81/db2_createTableSpace.ddl
db2 -tf ${UTILDIR}/DB2UDB_V81/Table.ddl
fi

if [ "$DB2VERSION" = "9.1" ]; then
db2 -tf ${UTILDIR}/DB2UDB_V81/db2_createTableSpace.ddl
db2 -tf ${UTILDIR}/DB2UDB_V81/Table.ddl
fi

db2 -tf ${UTILDIR}/DB2UDB_V81/createCore.sql
db2 -tf ${UTILDIR}/DB2UDB_V81/popCore.sql
db2 -td@ -f ${UTILDIR}/DB2UDB_V81/dm_db2_2.ddl
db2 -tf ${UTILDIR}/DB2UDB_V81/dmPrePopulate.sql

echo "insert into usersettings (USERNAME, TIMEZONEID, DST, BBREFRESHRATE) values ('$WAS_USER', 'GMT', 1, 5);" > $TEMP_FILE
echo "insert into usersettings_roles values(1, '$WAS_USER');" >> $TEMP_FILE
db2 -tf $TEMP_FILE
rm -rf $TEMP_FILE

db2 disconnect "$DBNAME"

if [ "$CREATE_DB" = "Y" ]; then
db2 update database configuration for "$DBNAME" using APPLHEAPSZ 512
db2 update database configuration for "$DBNAME" using LOGFILSIZ 8000
db2 update database configuration for "$DBNAME" using LOGPRIMARY 3
db2 update database configuration for "$DBNAME" using LOGSECOND 2
fi


printMessage crtdbDone

exit 0
